@@ -2,10 +2,7 @@
 
 #include "plugin.h"
 
-zathura_error_t
-pdf_page_render_cairo(zathura_page_t* page, void* data, cairo_t*
-    cairo, bool printing)
-{
+zathura_error_t pdf_page_render_cairo(zathura_page_t* page, void* data, cairo_t* cairo, bool printing) {
   if (page == NULL || data == NULL || cairo == NULL) {
     return ZATHURA_ERROR_INVALID_ARGUMENTS;
   }
